@@ -3,6 +3,9 @@
 from django.conf import settings
 
 
+if not hasattr(settings, "EXTRA_SETTINGS_CACHE_NAME"):
+    settings.EXTRA_SETTINGS_CACHE_NAME = "extra_settings"
+
 if not hasattr(settings, "EXTRA_SETTINGS_ENFORCE_UPPERCASE_SETTINGS"):
     settings.EXTRA_SETTINGS_ENFORCE_UPPERCASE_SETTINGS = True
 
