@@ -9,6 +9,7 @@ from extra_settings.models import Setting
 
 register = template.Library()
 
+
 @register.simple_tag(takes_context=True)
-def get_setting(context, name, default=''):
+def get_setting(context, name, default=""):
     return Setting.get(name, default)
